powered by
Construct a matrix of binary variables for calibration of sample weights according to known marginal population totals.
calibVars(x)
a vector that can be interpreted as factor, or a matrix or data.frame consisting of such variables.
data.frame
A matrix of binary variables that indicate membership to the corresponding factor levels.
calibWeights
# NOT RUN { data(eusilc) # default method aux <- calibVars(eusilc$rb090) head(aux) # data.frame method aux <- calibVars(eusilc[, c("db040", "rb090")]) head(aux) # }
Run the code above in your browser using DataLab