Usage
calibWeights(X, d, totals, q = NULL,
method = c("raking", "linear", "logit"),
bounds = c(0, 10), maxit = 500, tol = 1e-06,
eps = .Machine$double.eps)Arguments
X
a matrix of binary calibration variables (see
calibVars). d
a numeric vector giving the initial sample weights.
totals
a numeric vector of population totals corresponding to the
calibration variables in X.
q
a numeric vector of positive values accounting for
heteroscedasticity. Small values reduce the variation of
the g-weights.
method
a character string specifying the calibration method to be
used. Possible values are "linear" for the linear method,
"raking" for the multiplicative method known as raking and
"logit" for the logit me
bounds
a numeric vector of length two giving bounds for the g-weights
to be used in the logit method. The first value gives the lower bound
(which must be smaller than or equal to 1) and the second value gives the
upper bound (which must be large
maxit
a numeric value giving the maximum number of iterations.
tol
the desired accuracy for the iterative procedure.
eps
the desired accuracy for computing the Moore-Penrose generalized
inverse (see ginv).