inc
either a numeric vector giving the (equivalized disposable) income,
or (if data is not NULL) a character string, an integer or a
logical vector specifying the corresponding column of data.
weights
optional; either a numeric vector giving the personal sample
weights, or (if data is not NULL) a character string, an
integer or a logical vector specifying the corresponding column of
data.
years
optional; either a numeric vector giving the different years of
the survey, or (if data is not NULL) a character string,
an integer or a logical vector specifying the corresponding column of
data. If