incMedian(inc, weights = NULL, sort = NULL, years = NULL, data = NULL,
na.rm = FALSE)
Arguments
inc
either a numeric vector giving the (equivalized disposable)
income, or (if data is not NULL) a character string, an integer
or a logical vector specifying the corresponding column of data.
weights
optional; either a numeric vector giving the personal sample
weights, or (if data is not NULL) a character string, an
integer or a logical vector specifying the corresponding column of
data.
sort
optional; either a numeric vector giving the personal IDs to be
used as tie-breakers for sorting, or (if data is not NULL) a
character string, an integer or a logical vector specifying the corresponding
column of data.
years
optional; either a numeric vector giving the different years of
the survey, or (if data is not NULL) a character string, an
integer or a logical vector specifying the corresponding column of
data. If supplied, values are computed for each year.
data
an optional data.frame.
na.rm
a logical indicating whether missing values should be removed.
Value
A numeric vector containing the value(s) of the weighted median
income is returned.
Details
The implementation strictly follows the Eurostat definition.
References
Working group on Statistics on Income and Living Conditions
(2004) Common cross-sectional EU indicators based on EU-SILC; the gender pay
gap. EU-SILC 131-rev/04, Eurostat.