incQuintile(inc, weights = NULL, sort = NULL, years = NULL,
k = c(1, 4), data = NULL, na.rm = FALSE)data is not NULL) a character string, an integer or a
logical vector specifying the corresponding column of data.data is not NULL) a character string, an
integer or a logical vector specifying the corresponding column of
data.data is not NULL) a
character string, an integer or a logical vector specifying the
corresponding column of <data is not NULL) a character string,
an integer or a logical vector specifying the corresponding column of
data. If data.frame.years is NULL) or matrix (if years
is not NULL) containing the values of the weighted income quintiles
specified by k are returned.qsr, weightedQuantiledata(eusilc)
incQuintile("eqIncome", weights = "rb050", data = eusilc)Run the code above in your browser using DataLab