Learn R Programming

laeken (version 0.3.2)

laeken-package: Estimation of indicators on social exclusion and poverty

Description

Estimation of indicators on social exclusion and poverty, as well as Pareto tail modeling for empirical income distributions (including graphical tools).

Arguments

Details

ll{ Package: laeken Type: Package Version: 0.3.2 Date: 2012-03-19 Depends: R (>= 2.10.0), boot, MASS License: GPL (>= 2) }

Index: arpr At-risk-of-poverty rate arpt At-risk-of-poverty threshold bootVar Bootstrap variance and confidence intervals of indicators on social exclusion and poverty calibVars Construct a matrix of binary variables for calibration calibWeights Calibrate sample weights eqInc Equivalized disposable income eqSS Equivalized household size eusilc Synthetic EU-SILC survey data fitPareto Fit income distribution models with the Pareto distribution gini Gini coefficient gpg Gender pay (wage) gap. incMean Weighted mean income incMedian Weighted median income incQuintile Weighted income quintile is.indicator Utility functions for indicators on social exclusion and poverty laeken-package Estimation of indicators on social exclusion and poverty meanExcessPlot Mean excess plot minAMSE Weighted asymptotic mean squared error (AMSE) estimator paretoQPlot Pareto quantile plot paretoScale Estimate the scale parameter of a Pareto distribution paretoTail Pareto tail modeling for income distributions qsr Quintile share ratio replaceTail Replace observations under a Pareto model reweightOut Reweight outliers in the Pareto model rmpg Relative median at-risk-of-poverty gap shrinkOut Shrink outliers in the Pareto model thetaHill Hill estimator thetaISE Integrated squared error (ISE) estimator thetaLS Least squares (LS) estimator thetaMoment Moment estimator thetaPDC Partial density component (PDC) estimator thetaQQ QQ-estimator thetaTM Trimmed mean estimator thetaWML Weighted maximum likelihood estimator variance Variance and confidence intervals of indicators on social exclusion and poverty weightedMean Weighted mean weightedMedian Weighted median weightedQuantile Weighted quantiles

Further information is available in the following vignettes: ll{ laeken-pareto Robust Pareto Tail Modeling for the Estimation of Indicators on Social Exclusion using the R Package laeken (source, pdf) laeken-standard Standard Methods for Point Estimation of Indicators on Social Exclusion and Poverty using the R Package laeken (source, pdf) laeken-variance Variance Estimation of Indicators on Social Exclusion and Poverty using the R Package laeken (source, pdf) }