paretoQPlot(x, w = NULL, xlab = NULL, ylab = NULL,
interactive = TRUE, x0 = NULL, theta = NULL,
pch = par("pch"), cex = par("cex"), col = par("col"),
bg = "transparent", ...)x0 for the threshold,
theta for the shape parameter)points).plot.default.interactive is TRUE, the last selection
for the threshold is returned invisibly as an object of
class "paretoScale", which consists of the
following components:identify. For the usual
X11 device, the selection process is thus
terminated by pressing any mouse button other than the
first. For the quartz device (on Mac OS X
systems), the process is terminated either by a secondary
click (usually second mouse button or Ctrl-click)
or by pressing the ESC key.paretoScale, paretoTail,
minAMSE, meanExcessPlot,
identifydata(eusilc)
# equivalized disposable income is equal for each household
# member, therefore only one household member is taken
eusilc <- eusilc[!duplicated(eusilc$db030),]
# with sample weights
paretoQPlot(eusilc$eqIncome, w = eusilc$db090)
# without sample weights
paretoQPlot(eusilc$eqIncome)Run the code above in your browser using DataLab