paretoScale(x, w = NULL, groups = NULL, method = "VanKerm",
center = c("mean", "median"), probs = c(0.97, 0.98),
na.rm = FALSE)x (e.g., households). If supplied, each group of observations is
expected to have the same value in x (e.g., household income). Only
the values of eve"VanKerm", Van Kerm's method is used, which is a rule of thumb
specifically designed for the equivalized disposable income in EU-SILC data
(currently the only method impl"mean" for the
weighted mean and "median" for the weighted median. This is used if
method imethod is x should
be omitted."paretoScale", which consists of the following
components:minAMSE, paretoQPlot, meanExcessPlotdata(eusilc)
paretoScale(eusilc$eqIncome, eusilc$db090, groups = eusilc$db030)Run the code above in your browser using DataLab