an optional numeric vector giving the sample weights.
sorted
a logical indicating whether the observations in x are
already sorted.
na.rm
a logical indicating whether missing values in x should
be omitted.
Value
The weighted median of values in x is returned.
Details
The implementation strictly follows the Eurostat definition.
References
Working group on Statistics on Income and Living Conditions (2004) Common
cross-sectional EU indicators based on EU-SILC; the gender pay gap.
EU-SILC 131-rev/04, Eurostat.