incMedian(inc, weights = NULL, sort = NULL,
years = NULL, data = NULL, na.rm = FALSE)data is not NULL) a character string, an integer or a
logical vector specifying the corresponding column of data.data is not NULL) a character string, an
integer or a logical vector specifying the corresponding column of
data.data is not NULL) a
character string, an integer or a logical vector specifying the
corresponding column of <data is not NULL) a character string,
an integer or a logical vector specifying the corresponding column of
data. If data.frame.arpt, weightedMediandata(eusilc)
incMedian("eqIncome", weights = "rb050", data = eusilc)Run the code above in your browser using DataLab